@@ -1,11 +1,20 @@
+import inspect
+import os
+
 from jug.tests.task_reset import task_reset
 from jug.tests.utils import simple_execute
 from jug import task
 import jug.jug
 
+
+_jugdir = os.path.abspath(inspect.getfile(inspect.currentframe()))
+_jugdir = os.path.join(os.path.dirname(_jugdir), 'jugfiles')
+
+
 @task_reset
 def test_tasklets():
-    store, space = jug.jug.init('jug/tests/jugfiles/tasklets.py', 'dict_store')
+    jugfile = os.path.join(_jugdir, 'tasklets.py')
+    store, space = jug.jug.init(jugfile, 'dict_store')
     simple_execute()
     assert space['t0'].value() == 0
     assert space['t2'].value() == 4
@@ -14,7 +23,8 @@ def test_tasklets():
 
 @task_reset
 def test_iteratetask():
-    store, space = jug.jug.init('jug/tests/jugfiles/iteratetask.py', 'dict_store')
+    jugfile = os.path.join(_jugdir, 'iteratetask.py')
+    store, space = jug.jug.init(jugfile, 'dict_store')
     simple_execute()
     assert space['t0'].value() == 0
     assert space['t1'].value() == 2
@@ -22,13 +32,15 @@ def test_iteratetask():
 
 @task_reset
 def test_tasklet_dependencies():
-    store, space = jug.jug.init('jug/tests/jugfiles/tasklets.py', 'dict_store')
+    jugfile = os.path.join(_jugdir, 'tasklets.py')
+    store, space = jug.jug.init(jugfile, 'dict_store')
     assert not space['t0_2'].can_run()
 
 
 @task_reset
 def test_tasklet_dependencies():
-    store, space = jug.jug.init('jug/tests/jugfiles/slice_task.py', 'dict_store')
+    jugfile = os.path.join(_jugdir, 'slice_task.py')
+    store, space = jug.jug.init(jugfile, 'dict_store')
     simple_execute()
     assert space['z2'].value() == 0
 
