@@ -3,7 +3,8 @@ from os import system
 from nose.tools import with_setup
 
 import jug.utils
-import jug.task                             
+import jug.task
+from jug import value
 from jug.backends.dict_store import dict_store
 
 def _remove_test_file():
@@ -11,16 +12,19 @@ def _remove_test_file():
 
 @with_setup(teardown=_remove_test_file)
 def test_util_timed_path():
+    from jug.hash import hash_one
     Task = jug.task.Task
     jug.task.Task.store = dict_store()
     system("touch test_file")
     t0 = jug.utils.timed_path('test_file')
     t1 = jug.utils.timed_path('test_file')
-    assert t0.hash() == t1.hash()
+    h0 = hash_one(t0)
+    h1 = hash_one(t1)
+    assert h0 == h1
     sleep(1.1)
     system("touch test_file")
-    t1 = jug.utils.timed_path('test_file')
-    assert t0.hash() != t1.hash()
-    assert t0.run() == 'test_file'
-    assert t1.run() == 'test_file'
+    h1 = hash_one(t1)
+    assert h0 != h1
+    assert value(t0) == 'test_file'
+    assert value(t1) == 'test_file'
 
